@@ -1,10 +1,10 @@
 #' Eskin (ES) Measure
 #' 
-#' @description A function for calculation of a proximity (dissimilarity) matrix based on the ES similarity measure.
+#' @description The function calculates a dissimilarity matrix based on the ES similarity measure.
 #' 
-#' @param data A \emph{data.frame} or a \emph{matrix} with cases in rows and variables in colums.
+#' @param data A data.frame or a matrix with cases in rows and variables in colums.
 #' 
-#' @return The function returns an object of class "dist".
+#' @return The function returns an object of the class "dist".
 #' \cr
 #' 
 #' @details The Eskin similarity measure was proposed by Eskin et al. (2002) and examined by Boriah et al., (2008). It is constructed to assign
@@ -48,9 +48,6 @@ eskin <- function(data) {
     stop("The dissimilarity matrix CANNOT be calculated if the 'data' argument contains NA values.")
   }
   
-  r <- nrow(data)
-  s <- ncol(data)
-  
   rnames <- row.names(data)
   
   # recoding everything to factors and then to numeric values
@@ -58,25 +55,27 @@ eskin <- function(data) {
   data[!indx] <- lapply(data[!indx], function(x) as.factor(x))
   data <- as.data.frame(sapply(data, function(x) as.numeric(x)))
   
-  num_cat <- sapply(data, function(x) length(unique(x)))
   
-  agreement <- vector(mode="numeric", length=s)
-  eskin <- matrix(data=0,nrow=r,ncol=r)
-  row.names(eskin) <- rnames
+  # variable weighting
   
-  for (i in 1:(r-1)) {
-    for (j in (1+i):r) {
-      for (k in 1:s) {
-        if (data[i,k] == data[j,k]) {
-          agreement[k] <- 1
-        }
-        else {
-          agreement[k] <- num_cat[k]^2/(num_cat[k]^2 + 2)
-        }
-      }
-      eskin[i,j] <- 1/(1/s*(sum(agreement))) - 1
-      eskin[j,i] <- eskin[i,j]
-    }
-  }
-  return(as.dist(eskin))
+  # if (var.weights %in% c("none", "MI", "nMI", "MU", "MA") == TRUE) {
+  #   var.wgt <- WGT(data, var.weights, alpha)
+  
+  # OWN-DEFINED WEIGHTS
+  # } else if (is.numeric(var.weights) == TRUE) {
+  #    if(is.na(sum(var.weights >= 0)) | sum(var.weights >= 0)!=ncol(data)) {
+  #     stop("The vector of weights contains negative or missing values.")
+  #  }
+  #    var.wgt <- var.weights
+  
+  
+  # } else {
+  #   stop("Invalid weighting scheme.")
+  # }
+  
+  prox_matrix <- SIMILARITY(data, measure = "eskin")
+  
+  row.names(prox_matrix) <- rnames
+  
+  return(as.dist(prox_matrix))
 }
