@@ -1,10 +1,10 @@
 #' Lin (LIN) Measure
 #' 
-#' @description A function for calculation of a proximity (dissimilarity) matrix based on the LIN similarity measure.
+#' @description The function calculates a dissimilarity matrix based on the LIN similarity measure.
 #' 
-#' @param data A \emph{data.frame} or a \emph{matrix} with cases in rows and variables in colums.
+#' @param data A data.frame or a matrix with cases in rows and variables in colums.
 #' 
-#' @return The function returns an object of class "dist".
+#' @return The function returns an object of the class "dist".
 #' \cr
 #'
 #' @details The Lin measure was introduced by Lin (1998) and presented in (Boriah et al., 2008).
@@ -53,9 +53,6 @@ lin <- function(data) {
     stop("The dissimilarity matrix CANNOT be calculated if the 'data' argument contains NA values.")
   }
   
-  r <- nrow(data)
-  s <- ncol(data)
-  
   rnames <- row.names(data)
   
   # recoding everything to factors and then to numeric values
@@ -63,37 +60,27 @@ lin <- function(data) {
   data[!indx] <- lapply(data[!indx], function(x) as.factor(x))
   data <- as.data.frame(sapply(data, function(x) as.numeric(x)))
   
+  # variable weighting
   
-  freq.abs <- freq.abs(data)
-  freq.rel <- freq.abs/r
-
-  agreement <- vector(mode="numeric", length=s)
-  lin <- matrix(data=0,nrow=r,ncol=r)
-  row.names(lin) <- rnames
-  weights <- vector(mode="numeric", length=s)
+  # if (var.weights %in% c("none", "MI", "nMI", "MU", "MA") == TRUE) {
+  #   var.wgt <- WGT(data, var.weights, alpha)
   
-  for (i in 1:(r-1)) {
-    for (j in (1+i):r) {
-      for (k in 1:s) {
-        c <- data[i,k]
-        d <- data[j,k]
-        if (data[i,k] == data[j,k]) {
-          agreement[k] <- 2*log(freq.rel[c,k])
-        }
-        else {
-          agreement[k] <- 2*log(freq.rel[c,k] + freq.rel[d,k])
-        }
-        weights[k] <- log(freq.rel[c,k]) + log(freq.rel[d,k])
-      }
-      if (i == j) {
-        lin[i,j] <- 0
-      }
-      else {
-        lin[i,j] <- 1/(1/sum(weights)*(sum(agreement))) - 1
-        lin[j,i] <- lin[i,j]
-      }
-    }
-  }
-  lin[lin == -Inf] <- max(lin) + 1
-  return(as.dist(lin))
+  # OWN-DEFINED WEIGHTS
+  # } else if (is.numeric(var.weights) == TRUE) {
+  #    if(is.na(sum(var.weights >= 0)) | sum(var.weights >= 0)!=ncol(data)) {
+  #     stop("The vector of weights contains negative or missing values.")
+  #  }
+  #    var.wgt <- var.weights
+  
+  
+  # } else {
+  #   stop("Invalid weighting scheme.")
+  # }
+  freq.table <- freq.abs(data)
+  
+  prox_matrix <- SIMILARITY(data, measure = "lin", freq.table)
+  
+  row.names(prox_matrix) <- rnames
+  
+  return(as.dist(prox_matrix))
 }
\ No newline at end of file
