@@ -1,10 +1,10 @@
 #' Occurence Frequency (OF) Measure
 #' 
-#' @description A function for calculation of a proximity (dissimilarity) matrix based on the OF similarity measure.
+#' @description The function calculates a dissimilarity matrix based on the OF similarity measure.
 #'                                        
-#' @param data A \emph{data.frame} or a \emph{matrix} with cases in rows and variables in colums.
+#' @param data A data.frame or a matrix with cases in rows and variables in colums.
 #' 
-#' @return The function returns an object of class "dist".
+#' @return The function returns an object of the class "dist".
 #' \cr
 #'
 #' @details The OF (Occurrence Frequency) measure was originally constructed for the text mining tasks,
@@ -53,9 +53,6 @@ of <- function(data) {
     stop("The dissimilarity matrix CANNOT be calculated if the 'data' argument contains NA values.")
   }
   
-  r <- nrow(data)
-  s <- ncol(data)
-  
   rnames <- row.names(data)
   
   # recoding everything to factors and then to numeric values
@@ -63,30 +60,28 @@ of <- function(data) {
   data[!indx] <- lapply(data[!indx], function(x) as.factor(x))
   data <- as.data.frame(sapply(data, function(x) as.numeric(x)))
   
-
-  freq.abs <- freq.abs(data)
+  # variable weighting
   
-  agreement <- vector(mode="numeric", length=s)
-  of <- matrix(data=0,nrow=r,ncol=r)
-  row.names(of) <- rnames
+  # if (var.weights %in% c("none", "MI", "nMI", "MU", "MA") == TRUE) {
+  #   var.wgt <- WGT(data, var.weights, alpha)
+  
+  # OWN-DEFINED WEIGHTS
+  # } else if (is.numeric(var.weights) == TRUE) {
+  #    if(is.na(sum(var.weights >= 0)) | sum(var.weights >= 0)!=ncol(data)) {
+  #     stop("The vector of weights contains negative or missing values.")
+  #  }
+  #    var.wgt <- var.weights
   
   
-  for (i in 1:(r-1)) {
-    for (j in (1+i):r) {
-      for (k in 1:s) {
-        c <- data[i,k]
-        d <- data[j,k]
-        if (data[i,k] == data[j,k]) {
-          agreement[k] <- 1
-        }
-        else {
-          agreement[k] <- 1/(1+log(r/freq.abs[c,k])*log(r/freq.abs[d,k]))
-        }
-      }
-      of[i,j] <- 1/(1/s*(sum(agreement)))-1
-      of[j,i] <- of[i,j]
-    }
-  }
-  return(as.dist(of))
+  # } else {
+  #   stop("Invalid weighting scheme.")
+  # }
+  freq.table <- freq.abs(data)
+  
+  prox_matrix <- SIMILARITY(data, measure = "of", freq.table)
+  
+  row.names(prox_matrix) <- rnames
+  
+  return(as.dist(prox_matrix))
 }
 
