@@ -1,11 +1,11 @@
 #' Variable Mutability (VM) measure
 #'
-#' @description A function for calculation of a proximity (dissimilarity) matrix based on the VM similarity measure.
+#' @description The function calculates a dissimilarity matrix based on the VM similarity measure.
 #' \cr                                                           
 #'  
-#' @param data A \emph{data.frame} or a \emph{matrix} with cases in rows and variables in colums.
+#' @param data A data.frame or a matrix with cases in rows and variables in colums.
 #' 
-#' @return The function returns an object of class "dist".
+#' @return The function returns an object of the class "dist".
 #' \cr
 #' 
 #' @details The Variable Mutability similarity measure was introduced in (Sulc and Rezankova, 2019).
@@ -46,9 +46,6 @@ vm <- function(data) {
     stop("The dissimilarity matrix CANNOT be calculated if the 'data' argument contains NA values.")
   }
   
-  r <- nrow(data)
-  s <- ncol(data)
-  
   rnames <- row.names(data)
   
   # recoding everything to factors and then to numeric values
@@ -56,43 +53,27 @@ vm <- function(data) {
   data[!indx] <- lapply(data[!indx], function(x) as.factor(x))
   data <- as.data.frame(sapply(data, function(x) as.numeric(x)))
 
-
-  #number of categories
-  num_cat <- sapply(data, function(x) length(unique(x)))
-
-  #frequency tables
-  abs.freq <- freq.abs(data)
-  rel.freq <- abs.freq/r
-  rel2.freq <- rel.freq^2
-
-  #gini coefficient
-  sum_rel2.freq <- colSums(rel2.freq)
-  gini <- 1- sum_rel2.freq
-  norm_gini <- gini*num_cat/(num_cat-1)
-  norm_gini <- ifelse(is.nan(norm_gini),0,norm_gini)
+  # variable weighting
   
-  agreement <- vector(mode="numeric", length=s)
-  vm <- matrix(data=0,nrow=r,ncol=r)
-  row.names(vm) <- rnames
+  # if (var.weights %in% c("none", "MI", "nMI", "MU", "MA") == TRUE) {
+  #   var.wgt <- WGT(data, var.weights, alpha)
   
-  for (i in 1:(r-1)) {
-    for (j in (1+i):r) {
-      for (k in 1:s) {
-        if (data[i,k] == data[j,k]) {
-          agreement[k] <- norm_gini[k]
-       }
-       else {
-          agreement[k] <- 0
-        }
-      }
-      if (i == j) {
-        vm[i,j] <- 0
-      }
-      else {
-        vm[i,j] <- 1-1/s*(sum(agreement))
-        vm[j,i] <- vm[i,j]
-      }
-    }
-  }
-  return(as.dist(vm))
+  # OWN-DEFINED WEIGHTS
+  # } else if (is.numeric(var.weights) == TRUE) {
+  #    if(is.na(sum(var.weights >= 0)) | sum(var.weights >= 0)!=ncol(data)) {
+  #     stop("The vector of weights contains negative or missing values.")
+  #  }
+  #    var.wgt <- var.weights
+  
+  
+  # } else {
+  #   stop("Invalid weighting scheme.")
+  # }
+  freq.table <- freq.abs(data)
+  
+  prox_matrix <- SIMILARITY(data, measure = "vm", freq.table)
+  
+  row.names(prox_matrix) <- rnames
+  
+  return(as.dist(prox_matrix))
 }
\ No newline at end of file
